#!/usr/bin/perl

# Test POD correctness for Finance::PremiumBonds
#
# $Id: 2-pod.t 444 2008-09-04 18:55:10Z davidp $

use strict;
use Test::More;

eval "use Test::Pod 1.00";
plan skip_all => "Test::Pod 1.00 required for testing POD" if $@;
all_pod_files_ok();

